Welcome to PySiMMMulator docs!
===============================

.. include:: ../../README.md
    :parser: myst_parser.sphinx_

.. toctree::
   :maxdepth: 3
   :caption: Contents:

    Simulate <simulate.rst>
    Geos <geos.rst>
    Studies <study.rst>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
